
From: Andrew Morton <akpm@osdl.org>

fs/nfs/nfs-fscache.h:154: warning: function declaration isn't a prototype
fs/nfs/nfs-fscache.h:155: warning: function declaration isn't a prototype

Also fix some coding style nasties.

Cc: Steve Dickson <SteveD@redhat.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/nfs/nfs-fscache.h |   49 ++++++++++++++++++++++++++++---------------------
 1 files changed, 28 insertions(+), 21 deletions(-)

diff -puN fs/nfs/nfs-fscache.h~nfs-patch-for-fscache-warning-fix fs/nfs/nfs-fscache.h
--- 25/fs/nfs/nfs-fscache.h~nfs-patch-for-fscache-warning-fix	2005-06-18 00:04:40.000000000 -0700
+++ 25-akpm/fs/nfs/nfs-fscache.h	2005-06-18 00:05:01.000000000 -0700
@@ -44,8 +44,8 @@ nfs_renew_fscookie(struct nfs_server *se
 
 	return;
 }
-static inline void
-nfs4_fill_fscookie(struct super_block *sb)
+
+static inline void nfs4_fill_fscookie(struct super_block *sb)
 {
 	struct nfs_server *server = NFS_SB(sb);
 
@@ -53,17 +53,20 @@ nfs4_fill_fscookie(struct super_block *s
 	server->fscache = fscache_acquire_cookie(nfs_cache_netfs.primary_index,
 			       &nfs_cache_fh_index_def, server);
 	if (server->fscache == NULL) {
-		printk(KERN_WARNING "NFS4: No Fscache cookie. Turning Fscache off!\n");
-	} else /* reuse the NFS mount option */
+		printk(KERN_WARNING "NFS4: No Fscache cookie. Turning "
+				"Fscache off!\n");
+	} else {
+		/* reuse the NFS mount option */
 		server->flags |= NFS_MOUNT_FSCACHE;
+	}
 
 	dfprintk(FSCACHE,"NFS: nfs4 cookie (0x%p,0x%p/0x%p)\n",
 		sb, server, server->fscache);
 
 	return;
 }
-static inline void
-nfs_fill_fscookie(struct super_block *sb)
+
+static inline void nfs_fill_fscookie(struct super_block *sb)
 {
 	struct nfs_server *server = NFS_SB(sb);
 
@@ -72,13 +75,15 @@ nfs_fill_fscookie(struct super_block *sb
 			      &nfs_cache_fh_index_def, server);
 	if (server->fscache == NULL) {
 		server->flags &= ~NFS_MOUNT_FSCACHE;
-		printk(KERN_WARNING "NFS: No Fscache cookie. Turning Fscache off!\n");
+		printk(KERN_WARNING "NFS: No Fscache cookie. Turning "
+			"Fscache off!\n");
 	}
 	dfprintk(FSCACHE,"NFS: cookie (0x%p/0x%p/0x%p)\n",
 		sb, server, server->fscache);
 
 	return;
 }
+
 static inline void
 nfs_fhget_fscookie(struct super_block *sb, struct nfs_inode *nfsi)
 {
@@ -86,15 +91,16 @@ nfs_fhget_fscookie(struct super_block *s
 
 	nfsi->fscache = fscache_acquire_cookie(server->fscache, NULL, nfsi);
 	if (server->fscache == NULL)
-		printk(KERN_WARNING "NFS: NULL FScache cookie: sb 0x%p nfsi 0x%p\n", sb, nfsi);
+		printk(KERN_WARNING "NFS: NULL FScache cookie: "
+				"sb 0x%p nfsi 0x%p\n", sb, nfsi);
 
 	dfprintk(FSCACHE, "NFS: fhget new cookie (0x%p/0x%p/0x%p)\n",
 		sb, nfsi, nfsi->fscache);
 
 	return;
 }
-static inline void
-nfs_kill_fscookie(struct nfs_server *server)
+
+static inline void nfs_kill_fscookie(struct nfs_server *server)
 {
 	dfprintk(FSCACHE,"NFS: killing cookie (0x%p/0x%p)\n",
 		server, server->fscache);
@@ -104,8 +110,8 @@ nfs_kill_fscookie(struct nfs_server *ser
 
 	return;
 }
-static inline void
-nfs_clear_fscookie(struct nfs_inode *nfsi)
+
+static inline void nfs_clear_fscookie(struct nfs_inode *nfsi)
 {
 	dfprintk(FSCACHE, "NFS: clear cookie (0x%p/0x%p)\n",
 			nfsi, nfsi->fscache);
@@ -115,8 +121,8 @@ nfs_clear_fscookie(struct nfs_inode *nfs
 
 	return;
 }
-static inline void
-nfs_zap_fscookie(struct nfs_inode *nfsi)
+
+static inline void nfs_zap_fscookie(struct nfs_inode *nfsi)
 {
 	dfprintk(FSCACHE,"NFS: zapping cookie (0x%p/0x%p)\n",
 		nfsi, nfsi->fscache);
@@ -126,17 +132,18 @@ nfs_zap_fscookie(struct nfs_inode *nfsi)
 
 	return;
 }
-static inline int
-nfs_register_netfs(void)
+
+static inline int nfs_register_netfs(void)
 {
 	int err;
 
-	err = fscache_register_netfs(&nfs_cache_netfs, &nfs_cache_server_index_def);
+	err = fscache_register_netfs(&nfs_cache_netfs,
+					&nfs_cache_server_index_def);
 
 	return err;
 }
-static inline void
-nfs_unregister_netfs(void)
+
+static inline void nfs_unregister_netfs(void)
 {
 	fscache_unregister_netfs(&nfs_cache_netfs);
 
@@ -151,8 +158,8 @@ static inline void nfs_clear_fscookie(st
 static inline void nfs_zap_fscookie(struct nfs_inode *nfsi) {}
 static inline void
 	nfs_renew_fscookie(struct nfs_server *server, struct nfs_inode *nfsi) {}
-static inline int nfs_register_netfs() { return 0; }
-static inline void nfs_unregister_netfs() {}
+static inline int nfs_register_netfs(void) { return 0; }
+static inline void nfs_unregister_netfs(void) {}
 
 #endif
 #endif /* _NFS_FSCACHE_H */
_
